package edu.mermet.tp8;


import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Properties;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JDesktopPane;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JInternalFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;
import javax.swing.SwingUtilities;

import edu.mermet.tp8.actions.ActionAfficherBoutons;
import edu.mermet.tp8.actions.ActionAfficherConversion;
import edu.mermet.tp8.actions.ActionAfficherDiaporama;
import edu.mermet.tp8.actions.ActionAfficherTexte;
import edu.mermet.tp8.actions.ActionCommentFaire;
import edu.mermet.tp8.actions.ActionConfig;
import edu.mermet.tp8.boite.BoiteCommentFaire;
import edu.mermet.tp8.boite.BoiteConfig;
import edu.mermet.tp8.ecouteur.EcouteurAfficher;
import edu.mermet.tp8.ecouteur.EcouteurAuto;
import edu.mermet.tp8.fenetres.FenetreBoutons;
import edu.mermet.tp8.fenetres.FenetreConversion;
import edu.mermet.tp8.fenetres.FenetreDiaporama;
import edu.mermet.tp8.fenetres.FenetreSuggestion;
import edu.mermet.tp8.fenetres.FenetreTexte;

/**
 *
 * @author brunomermet
 */
public class Application extends JFrame {
    private JInternalFrame conversion;
    private JInternalFrame texte;
    private JInternalFrame diaporama;
    private JInternalFrame boutons;
    private JInternalFrame suggestions;
    private Action actionAfficherConversion;
    private Action actionAfficherTexte;
    private Action actionAfficherDiaporama;
    private Action actionAfficherBoutons;
    private Action actionCommentFaire;
    private Action actionConfig;
    public Application() {
        super("multi-fenêtres");
        this.setContentPane(new JDesktopPane());

        // ****** Barre de menu ******
        JMenuBar barre = new JMenuBar();
        // ------ menu Fichier ------
        JMenu menuFichier = new JMenu("Fichier");
        menuFichier.setMnemonic(KeyEvent.VK_F);
        JMenuItem quitter = new JMenuItem("Quitter");
        quitter.addActionListener (new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent aev) {
                System.exit(0);
            }
        });
        quitter.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_Q, InputEvent.CTRL_DOWN_MASK));
        menuFichier.add(quitter);
        barre.add(menuFichier);
        this.setJMenuBar(barre);
        // ------ menu Applications ------
        JMenu menuApplication = new JMenu("Applications");
        menuApplication.setMnemonic(KeyEvent.VK_A);
        actionAfficherConversion = new ActionAfficherConversion(this);
        JMenuItem itemConversion = new JMenuItem(actionAfficherConversion);
        menuApplication.add(itemConversion);
        actionAfficherTexte = new ActionAfficherTexte(this);
        JMenuItem itemTexte = new JMenuItem(actionAfficherTexte);
        menuApplication.add(itemTexte);
        actionAfficherDiaporama = new ActionAfficherDiaporama(this);
        JMenuItem itemDiaporama = new JMenuItem(actionAfficherDiaporama);
        menuApplication.add(itemDiaporama);
        actionAfficherBoutons = new ActionAfficherBoutons(this);
        JMenuItem itemBoutons = new JMenuItem(actionAfficherBoutons);
        menuApplication.add(itemBoutons);
        barre.add(menuApplication);
        
        JMenu menuAide = new JMenu("Aide");
        menuAide.setMnemonic(KeyEvent.VK_I);
        actionCommentFaire = new ActionCommentFaire(this);
        JMenuItem commentF = new JMenuItem(actionCommentFaire);
        menuAide.add(commentF);
        actionConfig = new ActionConfig(this);
        JMenuItem config = new JMenuItem(actionConfig);
        menuAide.add(config);
        barre.add(menuAide);
        // ****** Fin barre de menu ******
        
        
        
        // ****** Création des fenêtres ******
        // ------ fenêtre conversion ------
        conversion = new FenetreConversion(actionAfficherConversion);
        this.add(conversion);
        // ------ fenêtre texte ------
        texte = new FenetreTexte(actionAfficherTexte);
        this.add(texte);
        // ------ fenêtre diaporama ------
        diaporama = new FenetreDiaporama(actionAfficherDiaporama);
        this.add(diaporama);
        // ------ fenêtre boutons ------
        boutons = new FenetreBoutons(this,actionAfficherBoutons);
        this.add(boutons);
        // ****** Fin création fenêtres ******        
        
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setSize(600,300);
        this.setLocationRelativeTo(null);
        setVisible(true);
        afficherFenetre();
        suggestions = new FenetreSuggestion();
        add(suggestions);
    }

    public void enableConversion(boolean b) {
        actionAfficherConversion.setEnabled(b);
    }

    public void enableTexte(boolean b) {
        actionAfficherTexte.setEnabled(b);
    }

    public void enableDiaporama(boolean b) {
        actionAfficherDiaporama.setEnabled(b);
    }

    public void enableBoutons(boolean b) {
        actionAfficherBoutons.setEnabled(b);
    }
    
    public void enabledCommentFaire(boolean b) {
    	actionCommentFaire.setEnabled(b);
    }
    
    public void enabledConfig(boolean b) {
    	actionConfig.setEnabled(b);
    }

    public Action getActionAfficherConversion() {
        return actionAfficherConversion;
    }

    public Action getActionAfficherTexte() {
        return actionAfficherTexte;
    }

    public Action getActionAfficherDiaporama() {
        return actionAfficherDiaporama;
    }
    
    public Action getActionAfficherBouton() {
    	return actionAfficherBoutons;
    }
    
    public Action getActionCommentFaire() {
    	return actionCommentFaire;
    }
    
    public Action getActionConfig() {
    	return actionConfig;
    }
    
    public JInternalFrame getFenetreConversions() {
    	return conversion;
    }
    
    public JInternalFrame getFenetreTexte() {
    	return texte;
    }
    
    public JInternalFrame getFenetreDiapo() {
    	return diaporama;
    }
    
    public JInternalFrame getFenetreBoutons() {
    	return boutons;
    }
    
    public void afficherFenetre() {
    	try {
    		
    		Properties p = System.getProperties();        	
        	String name = p.getProperty("user.name");
    		
    		InputStream input = new FileInputStream("src/main/java/edu/mermet/tp8/donnesUtilisateur/"+ name +".properties");
    		
			Properties prop = new Properties();

            prop.load(input);
            
            if(prop.getProperty("conv").contains("Cacher")) {
            	conversion.setVisible(false);
            	
            	this.enableConversion(false);
            }else if (prop.getProperty("conv").contains("Afficher")) {
            	conversion.setVisible(true);
            	conversion.addInternalFrameListener(new EcouteurAfficher(conversion, actionAfficherConversion));
            	this.enableConversion(false);            	
            }
            
            if(prop.getProperty("texte").contains("Cacher")) {
            	texte.setVisible(false);
            	
            	this.enableTexte(false);
            }else if (prop.getProperty("texte").contains("Afficher")) {
            	texte.setVisible(true);
            	texte.addInternalFrameListener(new EcouteurAfficher(texte, actionAfficherTexte));
            	this.enableTexte(false);
            }
            
            if(prop.getProperty("diapo").contains("Cacher")) {
            	diaporama.setVisible(false);            	
            	this.enableDiaporama(false);
            }else if (prop.getProperty("diapo").contains("Afficher")) {
            	diaporama.setVisible(true);
            	diaporama.addInternalFrameListener(new EcouteurAfficher(diaporama, actionAfficherDiaporama));
            	this.enableDiaporama(false);          	
            }
            
            if(prop.getProperty("bouton").contains("Cacher")) {
            	boutons.setVisible(false);            	
            	this.enableBoutons(false);
            }else if (prop.getProperty("bouton").contains("Afficher")) {
            	boutons.setVisible(true);
            	boutons.addInternalFrameListener(new EcouteurAfficher(boutons, actionAfficherBoutons));
            	this.enableBoutons(false);            	
            }
            
		}catch (IOException ex) {
            ex.printStackTrace();
        }
    }
    
    public static void main(String[] args) {        
        try {
        	
        	Properties p = System.getProperties();        	
        	String name = p.getProperty("user.name");
        	
        	String adresse = "src/main/java/edu/mermet/tp8/donnesUtilisateur/"+ name +".properties";
        	File compFile = new File(adresse);
        	
        	if(!compFile.isFile()) {
        		OutputStream compOut = new FileOutputStream(adresse);
            	
            	Properties prop = new Properties();
            	prop.setProperty("competence", "0");
            	prop.setProperty("conv", "Auto");
                prop.setProperty("texte", "Auto");
                prop.setProperty("diapo", "Auto");
                prop.setProperty("bouton", "Auto");
                
            	prop.setProperty("1", "<html>Dans Aide, vous pourrez trouver l'item Comment Faire ?.<br>Comment Faire ? permet d'ouvrir la fenetre d'aide.</html>");
            	prop.setProperty("2", "Faites Ctrl+O pour ouvrir la fenêtre de conversion");
            	prop.setProperty("3", "Faites Ctrl+M pour ouvrir la fenêtre de Comment Faire ?");
            	prop.setProperty("4", "Faites Ctrl+B pour ouvrir la fenêtre de Boutons");
            	prop.setProperty("5", "Faites Ctrl+D pour ouvrir la fenêtre de Diaporama");
            	prop.setProperty("6", "Faites Ctrl+T pour ouvrir la fenêtre de Saisie de Texte");
            	prop.setProperty("7", "Faites Ctrl+Q pour quitter l'application");
            	prop.setProperty("8", "<html>Dans Aide, vous pourrez trouver l'item Configuration.<br>Configuration permet d'ouvrir la fenetre pour configurer l'affichage des autres fenêtres.</html>");
            	prop.setProperty("9", "<html>Dans Fichier, vous pourrez trouver l'item Quitter.<br>Quitter permet de fermer l'application.</html>");
            	prop.setProperty("10", "<html>Dans Applications, vous pourrez trouver l'item Conversion.<br>Conversion permet d'ouvrir la fenetre pour convertir des valeurs en Celsius en Farenheit et inversement.</html>");
            	prop.setProperty("11", "<html>Dans Applications, vous pourrez trouver l'item Diaporama.<br>Diaporama permet d'ouvrir la fenêtre avec un diaporama.</html>");
            	prop.setProperty("12", "<html>Dans Applications, vous pourrez trouver l'item Saisie de Texte.<br>Saisie de Texte permet d'ouvrir la fenetre pour saisir du texte.</html>");
            	prop.setProperty("13", "<html>Dans Applications, vous pourrez trouver l'item Boutons.<br>Boutons permet d'ouvrir la fenetre avec des boutons pour ouvrir les fenêtres Conversion, Saisie de Texte et Diaporama.</html>");
            	
            	for(int i = 1; i <= 13; i++) {
            		prop.setProperty("sug"+i, "yes");
            	}
            	
            	prop.store(compOut, null);
        	}
            

        } catch (IOException io) {
            io.printStackTrace();
        }
        
        
        /*try (OutputStream output2 = new FileOutputStream("src/main/java/edu/mermet/tp8/suggestion/suggestion.properties")) {
        	Properties prop2 = new Properties();
        	
        	
        	prop2.store(output2, null);
        	
        }catch (IOException io) {
            io.printStackTrace();
        }*/
	
        
        SwingUtilities.invokeLater(Application::new);
    }

    
}
